map.ag.bw <- function(out,path.list,plot.cov=NULL,plot.grad=NULL,alpha2=FALSE){

#
#  Mevin Hooten (20090703)
#
#
#  20090521:  Added alpha.also and cov.numb.
#  20090606:  spread out color ramp.
#  20090607:  Modified from 'map.post.old.R'
#  20090608:  Changed color ramp for alpha2.
#  20090609:  Changed alpha2 image to be X%*%beta2
#  20090703:  Changed color to grayscale.
#

####
####  Subroutines
####

require(splancs)

get.A <- function(mat){
  m=prod(dim(mat))
  dims=dim(mat)
  A.tilda.array=array(0,c(dims[1],dims[2],4))
  A.tilda.array[,2:dims[2],1]=mat[,1:(dims[2]-1)]-mat[,2:dims[2]]               # West
  A.tilda.array[2:dims[1],,2]=mat[1:(dims[1]-1),]-mat[2:dims[1],]               # North
  A.tilda.array[1:(dims[1]-1),,3]=mat[2:dims[1],]-mat[1:(dims[1]-1),]           # South
  A.tilda.array[,1:(dims[2]-1),4]=mat[,2:dims[2]]-mat[,1:(dims[2]-1)]           # East
  A.tilda=matrix(A.tilda.array,,4)
  A.tilda
}

####
####  Setup Variables 
####

dims=rev(out$dims)
#dims=out$dims
x=out$x
y=out$y

eps = max(min(diff(x)), min(diff(y)))
path = rbind(gps1.fall.path.list[[1]],gps1.spring.path.list[[1]])
buff.pts <- do.call('rbind',list(cbind(path[,1]+eps,path[,2]+eps),
                         cbind(path[,1]+eps,path[,2]-eps),
                         cbind(path[,1]-eps,path[,2]+eps),
                         cbind(path[,1]-eps,path[,2]-eps)))
path.hull = chull(buff.pts[, 1], buff.pts[, 2])
path.hull = c(path.hull, path.hull[1])
hullpoly = as.points(buff.pts[path.hull, 1], buff.pts[path.hull, 2])
x.lim = range(buff.pts[path.hull, 1])
y.lim = range(buff.pts[path.hull, 2])

grd.locs=expand.grid(rev(y),x)[,2:1]
in.idx=inout(as.points(grd.locs[,1],grd.locs[,2]),hullpoly,bound=TRUE)
in.mat.idx=matrix(in.idx,dims[2],dims[1])

alpha1.mean=out$alpha1.mean
alpha1.mean[!in.mat.idx]=NA
alpha2.mean=out$alpha2.mean
alpha2.mean[!in.mat.idx]=NA
gamma1.mean=out$gamma1.mean
gamma1.mean[!in.mat.idx]=NA
gamma2.mean=out$gamma2.mean
gamma2.mean[!in.mat.idx]=NA

####  Get alpha2 in terms of X%*%beta2

if(alpha2){
  alpha2.mean=out$X%*%apply(out$beta.save[out$alpha2.idx,-(1:out$n.burn)],1,mean)
  alpha2.mean[!in.mat.idx]=NA
}

####
####  Make Graphics
####

x11(width=8,height=10)
layout(matrix(1:4,2,2))

image(t(matrix(alpha1.mean,dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main=expression(alpha[1]),xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=gray.colors.rev(100),cex.main=2,axes=FALSE)
polymap(hullpoly,add=TRUE,lwd=2)
#box()
#lines(path,col=4)
#points(path,pch=".",col="white")


jet.full=gray.colors.rev(100)

#alpha2.quantiles=quantile(alpha2.mean,c(.1,.9),na.rm=TRUE)
#alpha2.mean[alpha2.mean<alpha2.quantiles[1]]=alpha2.quantiles[1]
#alpha2.mean[alpha2.mean>alpha2.quantiles[2]]=alpha2.quantiles[2]

alpha2.mag=max(abs(range(alpha2.mean,na.rm=TRUE)),na.rm=TRUE)
alpha2.rg=2*alpha2.mag
jet.portion.a1=(round((min(alpha2.mean,na.rm=TRUE)-(-alpha2.mag))/alpha2.rg*100)+1):round((max(alpha2.mean,na.rm=TRUE)-(-alpha2.mag))/alpha2.rg*100)

if(!alpha2){
  image(t(matrix(alpha2.mean,dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main=expression(alpha[2]),xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=jet.full[jet.portion.a1],cex.main=2,axes=FALSE)
}
if(alpha2){
  image(t(matrix(alpha2.mean,dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main=expression(alpha[2]),xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=gray.colors.rev(100),cex.main=2,axes=FALSE)
}
polymap(hullpoly,add=TRUE,lwd=2)
#box()
#lines(path,col=4)
#points(path,pch=".",col=1)
#points(path,pch=".",col="white")

image(t(matrix(gamma1.mean,dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main=expression(gamma[1]),xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=gray.colors.rev(100),cex.main=2,axes=FALSE)
polymap(hullpoly,add=TRUE,lwd=2)
#box()
#lines(path,col=4)
#points(path,pch=".",col=1)
#points(path,pch=".",col="white")

image(t(matrix(gamma2.mean,dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main=expression(gamma[2]),xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=gray.colors.rev(100),cex.main=2,axes=FALSE)
polymap(hullpoly,add=TRUE,lwd=2)
#box()
#lines(path,col=4)
#points(path,pch=".",col=1)
#points(path,pch=".",col="white")

if(!is.null(plot.cov)){
  x.tmp=X[,plot.cov]
  x.tmp[!in.mat.idx]=NA
  x11()
  image(t(matrix(x.tmp,dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main=paste("cov:",plot.cov),xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=gray.colors.rev(100))
#  image(t(matrix(gamma1.mean-gamma2.mean,dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main="gamma diff",xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=gray.colors.rev(100))
  polymap(hullpoly,add=TRUE)
  box()
  #lines(path,col=4)
  points(path,pch=".",col=1)
}

if(!is.null(plot.grad)){
  if(plot.grad=="alpha1"){grad.mat=out$alpha1.mean}
  if(plot.grad=="alpha2"){grad.mat=out$alpha2.mean}
  if(plot.grad=="gamma1"){grad.mat=out$gamma1.mean}
  if(plot.grad=="gamma2"){grad.mat=out$gamma2.mean}

  grad.out=get.A(matrix(grad.mat,dims[2],dims[1]))
  grad.out[!in.mat.idx,]=NA
  grad.mat[!in.mat.idx]=NA

  L=.1
  U=.9
  grad.quantiles=apply(grad.out,2,quantile,c(L,U),na.rm=TRUE)
  grad.out[grad.out[,1]<grad.quantiles[1,1],1]=grad.quantiles[1,1]
  grad.out[grad.out[,1]>grad.quantiles[2,1],1]=grad.quantiles[2,1]
  grad.out[grad.out[,2]<grad.quantiles[1,2],2]=grad.quantiles[1,2]
  grad.out[grad.out[,2]>grad.quantiles[2,2],2]=grad.quantiles[2,2]
  grad.out[grad.out[,3]<grad.quantiles[1,3],3]=grad.quantiles[1,3]
  grad.out[grad.out[,3]>grad.quantiles[2,3],3]=grad.quantiles[2,3]
  grad.out[grad.out[,4]<grad.quantiles[1,4],4]=grad.quantiles[1,4]
  grad.out[grad.out[,4]>grad.quantiles[2,4],4]=grad.quantiles[2,4]

  grad.min=apply(grad.out,2,min,na.rm=TRUE)
  grad.max=apply(grad.out,2,max,na.rm=TRUE)
  jet.full=gray.colors.rev(100)
  grad.mag=max(abs(grad.max),abs(grad.min))
  grad.rg=2*grad.mag

  jet.portion1=(round((grad.min[1]-min(grad.min))/grad.rg*100)+1):round((grad.max[1]-min(grad.min))/grad.rg*100)
  jet.portion2=(round((grad.min[2]-min(grad.min))/grad.rg*100)+1):round((grad.max[2]-min(grad.min))/grad.rg*100)
  jet.portion3=(round((grad.min[3]-min(grad.min))/grad.rg*100)+1):round((grad.max[3]-min(grad.min))/grad.rg*100)
  jet.portion4=(round((grad.min[4]-min(grad.min))/grad.rg*100)+1):round((grad.max[4]-min(grad.min))/grad.rg*100)

  x11()
  layout(matrix(c(0,1,0,2,3,4,0,5,0),3,3))


  image(t(matrix(grad.out[,1],dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main="west",xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=jet.full[jet.portion1],cex.main=2)
  polymap(hullpoly,add=TRUE)
  box()
  #lines(path,col=4)
#  points(path,pch=".",col=1)
  points(path,pch=".",col="white")

  image(t(matrix(grad.out[,2],dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main="north",xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=jet.full[jet.portion2],cex.main=2)
  polymap(hullpoly,add=TRUE)
  box()
  #lines(path,col=4)
#  points(path,pch=".",col=1)
  points(path,pch=".",col="white")

  image(t(matrix(grad.mat,dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main=expression(gamma[2]),xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=gray.colors.rev(100),cex.main=2)
  polymap(hullpoly,add=TRUE)
  box()
  #lines(path,col=4)
#  points(path,pch=".",col=1)
  points(path,pch=".",col="white")

  image(t(matrix(grad.out[,3],dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main="south",xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=jet.full[jet.portion3],cex.main=2)
  polymap(hullpoly,add=TRUE)
  box()
  #lines(path,col=4)
#  points(path,pch=".",col=1)
  points(path,pch=".",col="white")

  image(t(matrix(grad.out[,4],dims[2],dims[1]))[,dims[2]:1],x=x,y=y,asp=TRUE,main="east",xlab="",ylab="",xlim=x.lim,ylim=y.lim,col=jet.full[jet.portion4],cex.main=2)
  polymap(hullpoly,add=TRUE)
  box()
  #lines(path,col=4)
#  points(path,pch=".",col=1)
  points(path,pch=".",col="white")

}


}
