     \name{cellmove.jabes}
     \Rdversion{1.1}
     \alias{cellmove}
     \title{Cellular Movement Models}
     \description{
       Models for animal movement on heterogeneous landscapes. 
     }
     \seealso{
       \code{\link{crawl}}.
     }
     \examples{

#####
#####  Fall Path for Mule Deer
#####

##### Prepare GPS Data

data(cellmove.jabes)

gps1.fall.df=data.frame(cbind(cumsum(gps1.df[,2]),gps1.df[,3:4]))[1200:1328,]
names(gps1.fall.df)=c("time","x","y")
gps1.fall.df[,1]=gps1.fall.df[,1]-min(gps1.fall.df[,1])
gps1.fall.df$time <- round(gps1.fall.df$time,4)
gps1.fall.df=gps1.fall.df[!duplicated(gps1.fall.df$time),]

##### Clip Land Cover Data 

x.rng=range(c(gps1.df[,3],gps2.df[,3]))
y.rng=range(c(gps1.df[,4],gps2.df[,4]))
x.rng.2=x.rng
y.rng.2=y.rng
x.rng.2[1]=x.rng[1]-diff(x.rng)*.2
x.rng.2[2]=x.rng[2]+diff(x.rng)*.2
y.rng.2[1]=y.rng[1]-diff(y.rng)*.2
y.rng.2[2]=y.rng[2]+diff(y.rng)*.2
clip.idx=(lc.lg.df[,2]>=x.rng.2[1] & lc.lg.df[,2]<=x.rng.2[2] & 
	lc.lg.df[,3]>=y.rng.2[1] & lc.lg.df[,3]<=y.rng.2[2])
lc.clip.df=lc.lg.df[clip.idx,]
lc.clip.df[,1]=1:dim(lc.clip.df)[1]
lc.clip.df[,7]=cos((lc.clip.df[,7]+135)*pi/180)
rm(lc.lg.df)

##### Convert Land Cover Data to Column-Wise Format

x.locs=sort(unique(lc.clip.df[,2]))
y.locs=sort(unique(lc.clip.df[,3]))
mx=length(x.locs)
my=length(y.locs)
idx.2=as.vector(t(matrix(lc.clip.df[,1],mx,my))[my:1,])
lc.2.mat=lc.clip.df[idx.2,]
old.idx=lc.2.mat[,1]
lc.2.mat[,1]=1:(mx*my)

##### Resample Land Cover Data to Coarser Grid Cell Size 

my.sc=floor(my/10)
mx.sc=floor(mx/10)

lc.sc.out=scale.grid(lc.2.mat,mx.sc,my.sc)  #  This one takes a while.

#####  Rename Clipped Landcover  

x.sm=lc.sc.out$x;
y.sm=lc.sc.out$y;
mx.sm=length(x.sm);
my.sm=length(y.sm);
X.sm=lc.sc.out$X;
lc.sm.mat=lc.sc.out$lc.mat
lc.sm.out=list(X=X.sm,y=y.sm,x=x.sm,lc.mat=lc.sm.mat)

#####  Fit Crawl

gps1.fall.fit <- crwMLE(mov.model=~1,drift.model=FALSE,data=gps1.fall.df,coord=c("x","y"),
  Time.name="time",initial.state=list(a1.y=c(gps1.fall.df[1,3],0),a1.x=c(gps1.fall.df[1,2],0),P1.y=diag(2),
  P1.x=diag(2)),polar.coord=FALSE,control=list(maxit=2000,trace=1,REPORT=10))

#####  Get Predictions

gps1.fall.interp.times=seq(ceiling(min(gps1.fall.df[,1])),floor(max(gps1.fall.df[,1])),1)
gps1.fall.pred=crwPredict(object.crwFit=gps1.fall.fit,predTime=gps1.fall.interp.times,speedEst=TRUE,flat=FALSE)
gps1.fall.pred=as.flat(gps1.fall.pred)

crwPredictPlot(gps1.fall.pred)

#####  Get Cts Realizations from Fit

dev.new()
crwPredictPlot(gps1.fall.pred,"map")

gps1.fall.sim <- crwSimulator(gps1.fall.fit, gps1.fall.interp.times)
iter <- 500 
gps1.fall.path.list=vector("list",iter)
cols <- jet.colors(iter)
ln.w <- rep(0,iter)
for(i in 1:iter){
  samp <- crwPostIS(gps1.fall.sim, fullPost=FALSE)
  lines(samp$alpha.sim.x[,'mu'], samp$alpha.sim.y[,'mu'],col=cols[i])
  gps1.fall.path.list[[i]]=cbind(samp$alpha.sim.x[,'mu'], samp$alpha.sim.y[,'mu'])
}

##### Convert Cts. Realizations to Discrete Spatial Data

lc.sc.mat=lc.sc.out$lc.mat

gps1.fall.y=get.y(lc.sm.mat[,3:4],gps1.fall.interp.times,gps1.fall.path.list)

#####  Create Input List for MCMC Code

X=scale(lc.sm.out$X[,c(5,6,8,13:15)])
gps1.fall.input.list=list(dims=c(my.sm,mx.sm),yd.list=gps1.fall.y,X=X,n.ani=iter,
  x=lc.sm.out$x,y=lc.sm.out$y,lc.locs=lc.sm.out$lc.mat[,3:4])

#####  Remove all extra variables

rm(lc.sc.mat,lc.sc.out,X,lc.sm.mat,lc.sm.out,X.sm,lc.clip.df,gps2.df,gps1.fall.y,gps1.fall.pred,old.idx,idx.2,clip.idx,lc.2.mat)

#####  Run MCMC for CA Movement Model w/ Conjugate Gaussianity 

#gps1.fall.out=cellmove.mcmc(gps1.fall.input.list,1000)		# First Path Only

gps1.fall.out=cellmove.mcmc(gps1.fall.input.list,10000,,TRUE)	 

##### Summary Statistics for Path Choice and Landscape Effects

layout(matrix(1:4,4,1))
matplot(t(gps1.fall.out$beta.save[gps1.fall.out$alpha1.idx,]),type="l",lty=1,main="betas for alpha1",ylab="")
matplot(t(gps1.fall.out$beta.save[gps1.fall.out$alpha2.idx,]),type="l",lty=1,main="betas for alpha2",ylab="")
matplot(t(gps1.fall.out$beta.save[gps1.fall.out$gamma1.idx,]),type="l",lty=1,main="betas for gamma1",ylab="")
matplot(t(gps1.fall.out$beta.save[gps1.fall.out$gamma2.idx,]),type="l",lty=1,main="betas for gamma2",ylab="")

plot.betas(gps1.fall.out)

##### Plot Posterior Images

map.ag(gps1.fall.out,gps1.fall.path.list,,"gamma2")

#####
#####  Spring Path for Mule Deer
#####

##### Prepare GPS Data

data(cellmove.jabes)

gps1.spring.df=data.frame(cbind(cumsum(gps1.df[,2]),gps1.df[,3:4]))[356:400,]
names(gps1.spring.df)=c("time","x","y")
gps1.spring.df[,1]=gps1.spring.df[,1]-min(gps1.spring.df[,1])
gps1.spring.df$time <- round(gps1.spring.df$time,4)
gps1.spring.df=gps1.spring.df[!duplicated(gps1.spring.df$time),]

#####  Fit Crawl

gps1.spring.fit <- crwMLE(mov.model=~1,drift.model=FALSE,data=gps1.spring.df,coord=c("x","y"),
  Time.name="time",initial.state=list(a1.y=c(gps1.spring.df[1,3],0),a1.x=c(gps1.spring.df[1,2],0),P1.y=diag(2),
  P1.x=diag(2)),polar.coord=FALSE,control=list(maxit=2000,trace=1,REPORT=10))

#####  Get Predictions

gps1.spring.interp.times=seq(ceiling(min(gps1.spring.df[,1])),floor(max(gps1.spring.df[,1])),1)
gps1.spring.pred=crwPredict(object.crwFit=gps1.spring.fit,predTime=gps1.spring.interp.times,speedEst=TRUE,flat=FALSE)
gps1.spring.pred=as.flat(gps1.spring.pred)

#####  Get Cts Realizations from Fit

dev.new()
crwPredictPlot(gps1.spring.pred,"map")

gps1.spring.sim <- crwSimulator(gps1.spring.fit, gps1.spring.interp.times)
iter <- 500 
gps1.spring.path.list=vector("list",iter)
cols <- jet.colors(iter)
ln.w <- rep(0,iter)
for(i in 1:iter){
  samp <- crwPostIS(gps1.spring.sim, fullPost=FALSE)
  lines(samp$alpha.sim.x[,'mu'], samp$alpha.sim.y[,'mu'],col=cols[i])
  gps1.spring.path.list[[i]]=cbind(samp$alpha.sim.x[,'mu'], samp$alpha.sim.y[,'mu'])
}

##### Convert Cts. Realizations to Discrete Spatial Data

lc.sc.mat=lc.sc.out$lc.mat

gps1.spring.y=get.y(lc.sm.mat[,3:4],gps1.spring.interp.times,gps1.spring.path.list)

#####  Create Input List for MCMC Code

X=scale(lc.sm.out$X[,c(5,6,8,13:15)])
gps1.spring.input.list=list(dims=c(my.sm,mx.sm),yd.list=gps1.spring.y,X=X,n.ani=iter,
  x=lc.sm.out$x,y=lc.sm.out$y,lc.locs=lc.sm.out$lc.mat[,3:4])

#####  Run MCMC for CA Movement Model w/ Conjugate Gaussianity 

gps1.spring.out=cellmove.mcmc(gps1.spring.input.list,10000,,TRUE)	 

##### Summary Statistics for Path Choice and Landscape Effects

layout(matrix(1:4,4,1))
matplot(t(gps1.spring.out$beta.save[gps1.spring.out$alpha1.idx,]),type="l",lty=1,main="betas for alpha1",ylab="")
matplot(t(gps1.spring.out$beta.save[gps1.spring.out$alpha2.idx,]),type="l",lty=1,main="betas for alpha2",ylab="")
matplot(t(gps1.spring.out$beta.save[gps1.spring.out$gamma1.idx,]),type="l",lty=1,main="betas for gamma1",ylab="")
matplot(t(gps1.spring.out$beta.save[gps1.spring.out$gamma2.idx,]),type="l",lty=1,main="betas for gamma2",ylab="")

plot.betas(gps1.spring.out)

##### Plot Posterior Images

map.ag(gps1.spring.out,gps1.spring.path.list,,"gamma2")

#####  END



     }
     \keyword{file}

